summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorDragorn421 <Dragorn421@users.noreply.github.com>2023-09-22 20:48:09 +0200
committerGitHub <noreply@github.com>2023-09-22 14:48:09 -0400
commitfefeb369dd19172d5eb419f8c8373cfb10d59d19 (patch)
treea51cf7c4b4feac8f5640afd2d7564fdef9705d75 /include
parent4842f62833eda04e3883c9ddb4cff133cea27cb0 (diff)
Name the main pause state and add placeholder enum for main (sub)states (#1551)
Diffstat (limited to 'include')
-rw-r--r--include/z64pause.h18
1 files changed, 16 insertions, 2 deletions
diff --git a/include/z64pause.h b/include/z64pause.h
index f25d5c6ed..1cc810c31 100644
--- a/include/z64pause.h
+++ b/include/z64pause.h
@@ -33,7 +33,7 @@ typedef enum {
/* 3 */ PAUSE_STATE_INIT, // Load data and initialize/setup various things.
/* 4 */ PAUSE_STATE_OPENING_1, // Animate the pause menu coming together with rotations and other animations.
/* 5 */ PAUSE_STATE_OPENING_2, // Finish some animations for opening the menu.
/* 6 */ PAUSE_STATE_6, // Pause menu ready for player inputs.
/* 7 */ PAUSE_STATE_SAVE_PROMPT, // Save prompt in the pause menu
/* 8 */ PAUSE_STATE_8,
/* 9 */ PAUSE_STATE_9,
@@ -55,6 +55,20 @@ typedef enum {
#define IS_PAUSED(pauseCtx) \
(((pauseCtx)->state != PAUSE_STATE_OFF) || ((pauseCtx)->debugState != 0))
+// Sub-states of PAUSE_STATE_MAIN
+typedef enum {
+ /* 0 */ PAUSE_MAIN_STATE_IDLE,
+ /* 1 */ PAUSE_MAIN_STATE_1,
+ /* 2 */ PAUSE_MAIN_STATE_2,
+ /* 3 */ PAUSE_MAIN_STATE_3,
+ /* 4 */ PAUSE_MAIN_STATE_4,
+ /* 5 */ PAUSE_MAIN_STATE_5,
+ /* 6 */ PAUSE_MAIN_STATE_6,
+ /* 7 */ PAUSE_MAIN_STATE_7,
+ /* 8 */ PAUSE_MAIN_STATE_8,
+ /* 9 */ PAUSE_MAIN_STATE_9
+} PauseMainState;
+
typedef struct {
/* 0x0000 */ View view;
/* 0x0128 */ u8* iconItemSegment;
@@ -83,7 +97,7 @@ typedef struct {
/* 0x01D4 */ u16 state;
/* 0x01D6 */ u16 debugState;
/* 0x01D8 */ Vec3f eye;
- /* 0x01E4 */ u16 unk_1E4;
+ /* 0x01E4 */ u16 mainState;
/* 0x01E6 */ u16 mode;
/* 0x01E8 */ u16 pageIndex; // "kscp_pos"
/* 0x01EA */ u16 unk_1EA;
@@ -33,7 +33,7 @@ typedef enum {
/* 4 */ PAUSE_STATE_OPENING_1, // Animate the pause menu coming together with rotations and other animations.
/* 5 */ PAUSE_STATE_OPENING_2, // Finish some animations for opening the menu.
- /* 6 */ PAUSE_STATE_6, // Pause menu ready for player inputs.
+ /* 6 */ PAUSE_STATE_MAIN, // Pause menu ready for player inputs.
/* 7 */ PAUSE_STATE_SAVE_PROMPT, // Save prompt in the pause menu
/* 8 */ PAUSE_STATE_8,